@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -48,7 +48,7 @@ if (!$core->error->flag() && $blog_id && !empty($_POST['del']))
 	}
 }
 
-dcPage::open('Delete a blog');
+dcPage::open(__('Delete a blog'));
 
 if (!$core->error->flag())
 {
