@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -218,17 +218,15 @@ if (!$theme_conf_mode)
 	'<h2>'.html::escapeHTML($core->blog->name).' &rsaquo; <span class="page-title">'.__('Blog appearance').'</span></h2>';
 	
 	if (!empty($_GET['upd'])) {
-		echo '<p class="message">'.__('Theme has been successfully changed.').'</p>';
+		dcPage::message(__('Theme has been successfully changed.'));
 	}
 	
 	if (!empty($_GET['added'])) {
-		echo '<p class="message">'.
-		($_GET['added'] == 2 ? __('Theme has been successfully upgraded') : __('Theme has been successfully installed.')).
-		'</p>';
+		dcPage::message(($_GET['added'] == 2 ? __('Theme has been successfully upgraded') : __('Theme has been successfully installed.')));
 	}
 	
 	if (!empty($_GET['del'])) {
-		echo '<p class="message">'.__('Theme has been successfully deleted.').'</p>';
+		dcPage::message(__('Theme has been successfully deleted.'));
 	}
 	
 	if ($can_install) {
@@ -333,7 +331,7 @@ else
 	$core->themes->loadModuleL10Nresources($core->blog->settings->system->theme,$_lang);
 	echo
 	'<h2>'.html::escapeHTML($core->blog->name).
-	' &rsaquo; <a href="blog_theme.php">'.__('Blog appearance').'</a> &rsaquo; <span class="page-title">'.__('Theme configuration').'<span class="page-title"></h2>'.
+	' &rsaquo; <a href="blog_theme.php">'.__('Blog appearance').'</a> &rsaquo; <span class="page-title">'.__('Theme configuration').'</span></h2>'.
 	'<p><a class="back" href="blog_theme.php">'.__('back').'</a></p>';
 	
 	try
