@@ -65,5 +65,5 @@ $(function() {
 	// allow to hide quick entry div, and remember choice
 	$('#quick h3').toggleWithLegend($('#quick').children().not('h3'),{
 		cookie: 'dcx_quick_entry'
-	}, positionFooter);
+	});
 });
