@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -15,6 +15,7 @@ require dirname(__FILE__).'/../inc/admin/prepend.php';
 dcPage::check('usage,contentadmin');
 
 $params = array();
+$action = '';
 
 /* Actions
 -------------------------------------------------------- */
@@ -58,6 +59,11 @@ if (!empty($_POST['action']) && !empty($_POST['entries']))
 	
 	$posts = $core->blog->getPosts($params);
 	
+	$posts_ids = array();
+	while ($posts->fetch())	{
+		$posts_ids[] = $posts->post_id;
+	}
+	
 	# --BEHAVIOR-- adminPostsActions
 	$core->callBehavior('adminPostsActions',$core,$posts,$action,$redir);
 	
@@ -72,9 +78,7 @@ if (!empty($_POST['action']) && !empty($_POST['entries']))
 		
 		try
 		{
-			while ($posts->fetch()) {
-				$core->blog->updPostStatus($posts->post_id,$status);
-			}
+			$core->blog->updPostsStatus($posts_ids,$status);
 			
 			http::redirect($redir);
 		}
@@ -87,9 +91,7 @@ if (!empty($_POST['action']) && !empty($_POST['entries']))
 	{
 		try
 		{
-			while ($posts->fetch()) {
-				$core->blog->updPostSelected($posts->post_id,$action == 'selected');
-			}
+			$core->blog->updPostsSelected($posts_ids,$action == 'selected');
 			
 			http::redirect($redir);
 		}
@@ -102,12 +104,18 @@ if (!empty($_POST['action']) && !empty($_POST['entries']))
 	{
 		try
 		{
-			while ($posts->fetch()) {
+			// Backward compatibility
+			foreach($posts_ids as $post_id)
+			{
 				# --BEHAVIOR-- adminBeforePostDelete
-				$core->callBehavior('adminBeforePostDelete',$posts->post_id);				
-				$core->blog->delPost($posts->post_id);
+				$core->callBehavior('adminBeforePostDelete',(integer) $post_id);
 			}
 			
+			# --BEHAVIOR-- adminBeforePostsDelete
+			$core->callBehavior('adminBeforePostsDelete',$posts_ids);
+			
+			$core->blog->delPosts($posts_ids);
+			
 			http::redirect($redir);
 		}
 		catch (Exception $e)
@@ -120,11 +128,8 @@ if (!empty($_POST['action']) && !empty($_POST['entries']))
 	{
 		try
 		{
-			while ($posts->fetch())
-			{
-				$new_cat_id = (integer) $_POST['new_cat_id'];
-				$core->blog->updPostCategory($posts->post_id,$new_cat_id);
-			}
+			$core->blog->updPostsCategory($posts_ids,$_POST['new_cat_id']);
+			
 			http::redirect($redir);
 		}
 		catch (Exception $e)
@@ -143,12 +148,9 @@ if (!empty($_POST['action']) && !empty($_POST['entries']))
 				throw new Exception(__('This user does not exist'));
 			}
 			
-			while ($posts->fetch())
-			{
-				$cur = $core->con->openCursor($core->prefix.'post');
-				$cur->user_id = $new_user_id;
-				$cur->update('WHERE post_id = '.(integer) $posts->post_id);
-			}
+			$cur = $core->con->openCursor($core->prefix.'post');
+			$cur->user_id = $new_user_id;
+			$cur->update('WHERE post_id '.$core->con->in($posts_ids));
 			
 			http::redirect($redir);
 		}
@@ -157,12 +159,48 @@ if (!empty($_POST['action']) && !empty($_POST['entries']))
 			$core->error->add($e->getMessage());
 		}
 	}
+	elseif ($action == 'lang' && isset($_POST['new_lang']))
+	{
+		$new_lang = $_POST['new_lang'];
+		try
+		{
+			$cur = $core->con->openCursor($core->prefix.'post');
+			$cur->post_lang = $new_lang;
+			$cur->update('WHERE post_id '.$core->con->in($posts_ids));
+			
+			http::redirect($redir);
+		}
+		catch (Exception $e)
+		{
+			$core->error->add($e->getMessages());
+		}
+	}
 }
 
 /* DISPLAY
 -------------------------------------------------------- */
+// Get current users list
+$usersList = '';
+if ($action == 'author' && $core->auth->check('admin',$core->blog->id)) {
+	$params = array(
+		'limit' => 100,
+		'order' => 'nb_post DESC'
+		);
+	$rs = $core->getUsers($params);
+	while ($rs->fetch())
+	{
+		$usersList .= ($usersList != '' ? ',' : '').'"'.$rs->user_id.'"';
+	}
+}
 dcPage::open(
 	__('Entries'),
+	'<script type="text/javascript">'."\n".
+	"//<![CDATA[\n".
+	'usersList = ['.$usersList.']'."\n".
+	"\n//]]>\n".
+	"</script>\n".
+	dcPage::jsLoad('js/jquery/jquery.autocomplete.js').
+	dcPage::jsLoad('js/_posts_actions.js').
 	dcPage::jsMetaEditor().
 	# --BEHAVIOR-- adminBeforePostDelete
 	$core->callBehavior('adminPostsActionsHeaders')
@@ -235,6 +273,40 @@ if ($action == 'category')
 	'<input type="submit" value="'.__('Save').'" /></p>'.
 	'</form>';
 }
+elseif ($action == 'lang')
+{
+	echo '<h2 class="page-title">'.__('Change language for entries').'</h2>';
+	
+	# lang list
+	# Languages combo
+	$rs = $core->blog->getLangs(array('order'=>'asc'));
+	$all_langs = l10n::getISOcodes(0,1);
+	$lang_combo = array('' => '', __('Most used') => array(), __('Available') => l10n::getISOcodes(1,1));
+	while ($rs->fetch()) {
+		if (isset($all_langs[$rs->post_lang])) {
+			$lang_combo[__('Most used')][$all_langs[$rs->post_lang]] = $rs->post_lang;
+			unset($lang_combo[__('Available')][$all_langs[$rs->post_lang]]);
+		} else {
+			$lang_combo[__('Most used')][$rs->post_lang] = $rs->post_lang;
+		}
+	}
+	unset($all_langs);
+	unset($rs);
+	
+	echo
+	'<form action="posts_actions.php" method="post">'.
+	'<p><label for="new_lang" class="classic">'.__('Entry lang:').' '.
+	form::combo('new_lang',$lang_combo,'').
+	'</label> ';
+	
+	echo
+	$hidden_fields.
+	$core->formNonce().
+	form::hidden(array('action'),'lang').
+	'<input type="submit" value="'.__('Save').'" /></p>'.
+	'</form>';
+
+}
 elseif ($action == 'author' && $core->auth->check('admin',$core->blog->id))
 {
 	echo '<h2 class="page-title">'.__('Change author for entries').'</h2>';
