@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -41,6 +41,7 @@ if ($core->auth->isSuperAdmin()) {
 	$user_ui_hide_std_favicon = $core->auth->user_prefs->interface->hide_std_favicon;
 }
 $user_ui_iconset = @$core->auth->user_prefs->interface->iconset;
+$user_ui_nofavmenu = $core->auth->user_prefs->interface->nofavmenu;
 
 $default_tab = !empty($_GET['tab']) ? html::escapeHTML($_GET['tab']) : 'user-profile';
 
@@ -160,8 +161,8 @@ if (isset($_POST['user_post_format']))
 		
 		$cur->user_options = new ArrayObject($user_options);
 		
-		# --BEHAVIOR-- adminBeforeUserUpdate
-		$core->callBehavior('adminBeforeUserUpdate',$cur,$core->auth->userID());
+		# --BEHAVIOR-- adminBeforeUserOptionsUpdate
+		$core->callBehavior('adminBeforeUserOptionsUpdate',$cur,$core->auth->userID());
 		
 		# Update user prefs
 		$core->auth->user_prefs->dashboard->put('doclinks',!empty($_POST['user_dm_doclinks']),'boolean');
@@ -174,12 +175,13 @@ if (isset($_POST['user_post_format']))
 			$core->auth->user_prefs->interface->put('hide_std_favicon',!empty($_POST['user_ui_hide_std_favicon']),'boolean',null,true,true);
 		}
 		$core->auth->user_prefs->interface->put('iconset',(!empty($_POST['user_ui_iconset']) ? $_POST['user_ui_iconset'] : ''));
+		$core->auth->user_prefs->interface->put('nofavmenu',!empty($_POST['user_ui_nofavmenu']),'boolean');
 		
 		# Udate user
 		$core->updUser($core->auth->userID(),$cur);
 		
-		# --BEHAVIOR-- adminAfterUserUpdate
-		$core->callBehavior('adminAfterUserUpdate',$cur,$core->auth->userID());
+		# --BEHAVIOR-- adminAfterUserOptionsUpdate
+		$core->callBehavior('adminAfterUserOptionsUpdate',$cur,$core->auth->userID());
 		
 		http::redirect('preferences.php?updated=1');
 	}
@@ -340,7 +342,7 @@ if (!empty($_POST['replace']) && $core->auth->isSuperAdmin()) {
 dcPage::open($page_title,
 	dcPage::jsLoad('js/_preferences.js').
 	($user_acc_nodragdrop ? '' : dcPage::jsLoad('js/_preferences-dragdrop.js')).
-	dcPage::jsLoad('js/jquery/jquery-ui-1.8.12.custom.min.js').
+	dcPage::jsLoad('js/jquery/jquery-ui.custom.js').
 	dcPage::jsPageTabs($default_tab).
 	dcPage::jsConfirmClose('user-form').
 	
@@ -349,22 +351,22 @@ dcPage::open($page_title,
 );
 
 if (!empty($_GET['upd'])) {
-		echo '<p class="message">'.__('Personal information has been successfully updated.').'</p>';
+	dcPage::message(__('Personal information has been successfully updated.'));
 }
 if (!empty($_GET['updated'])) {
-		echo '<p class="message">'.__('Personal options has been successfully updated.').'</p>';
+	dcPage::message(__('Personal options has been successfully updated.'));
 }
 if (!empty($_GET['append'])) {
-		echo '<p class="message">'.__('Favorites have been successfully added.').'</p>';
+	dcPage::message(__('Favorites have been successfully added.'));
 }
 if (!empty($_GET['neworder'])) {
-	echo '<p class="message">'.__('Favorites have been successfully updated.').'</p>';
+	dcPage::message(__('Favorites have been successfully updated.'));
 }
 if (!empty($_GET['removed'])) {
-		echo '<p class="message">'.__('Favorites have been successfully removed.').'</p>';
+	dcPage::message(__('Favorites have been successfully removed.'));
 }
 if (!empty($_GET['replaced'])) {
-		echo '<p class="message">'.__('Default favorites have been successfully updated.').'</p>';
+	dcPage::message(__('Default favorites have been successfully updated.'));
 }
 
 echo '<h2>'.html::escapeHTML($core->blog->name).' &rsaquo; <span class="page-title">'.$page_title.'</span></h2>';
@@ -455,7 +457,11 @@ __('Enable WYSIWYG mode').'</label></p>'.
 
 '<p><label for="user_ui_enhanceduploader" class="classic">'.
 form::checkbox('user_ui_enhanceduploader',1,$user_ui_enhanceduploader).' '.
-__('Activate enhanced uploader in media manager').'</label></p>';
+__('Activate enhanced uploader in media manager').'</label></p>'.
+
+'<p><label for="user_ui_nofavmenu" class="classic">'.
+form::checkbox('user_ui_nofavmenu',1,$user_ui_nofavmenu).' '.
+__('Hide My favorites menu').'</label></p>';
 
 if (count($iconsets_combo) > 1) {
 	echo 
@@ -622,4 +628,4 @@ echo '</div>'; # user-favorites
 
 dcPage::helpBlock('core_user_pref');
 dcPage::close();
-?>
+?>
\ No newline at end of file
