@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -193,42 +193,92 @@ class dcBlog
 	*/
 	public function triggerComment($id,$del=false)
 	{
-		$id = (integer) $id;
+		$this->triggerComments($id,$del);
+	}
+	
+	/**
+	Updates comments and trackbacks counters in post table. Should be called
+	every time comments or trackbacks are added, removed or changed there status.
+	
+	@param	ids		<b>mixed</b>		Comment(s) ID(s)
+	@param	del		<b>boolean</b>		If comment is delete, set this to true
+	@param	affected_posts		<b>mixed</b>		Posts(s) ID(s)
+	*/
+	public function triggerComments($ids, $del=false, $affected_posts=null)
+	{
+		$co_ids = dcUtils::cleanIds($ids);
+		$a_ids = dcUtils::cleanIds($affected_posts);
+		$a_tbs = array();
 		
-		$strReq = 'SELECT post_id, comment_trackback '.
+		# a) Retrieve posts affected by comments edition
+		if (empty($a_ids)) {
+			$strReq = 
+				'SELECT post_id, comment_trackback '.
 				'FROM '.$this->prefix.'comment '.
-				'WHERE comment_id = '.$id.' ';
+				'WHERE comment_id'.$this->con->in($co_ids).
+				'GROUP BY post_id,comment_trackback';
+			
+			$rs = $this->con->select($strReq);
+			
+			while ($rs->fetch()) {
+				$a_ids[] = (integer) $rs->post_id;
+				$a_tbs[] = (integer) $rs->comment_trackback;
+			}
+		}
 		
-		$rs = $this->con->select($strReq);
-		
-		$post_id = $rs->post_id;
-		$tb = (boolean) $rs->comment_trackback;
-		
-		$strReq = 'SELECT COUNT(post_id) '.
-				'FROM '.$this->prefix.'comment '.
-				'WHERE post_id = '.(integer) $post_id.' '.
-				'AND comment_trackback = '.(integer) $tb.' '.
-				'AND comment_status = 1 ';
+		# b) Count comments of each posts previously retrieved
+		# Note that this does not return posts without comment
+		$strReq = 
+			'SELECT post_id, COUNT(post_id) AS nb_comment,comment_trackback '.
+			'FROM '.$this->prefix.'comment '.
+			'WHERE comment_status = 1 '.
+			(count($a_ids) > 0 ? 'AND post_id'.$this->con->in($a_ids) : ' ');
 		
 		if ($del) {
-			$strReq .= 'AND comment_id <> '.$id.' ';
+			$strReq .= 
+				'AND comment_id NOT'.$this->con->in($co_ids);
 		}
 		
+		$strReq .= 
+			'GROUP BY post_id,comment_trackback';
+		
 		$rs = $this->con->select($strReq);
 		
+		$b_ids = $b_tbs = $b_nbs = array();
+		while ($rs->fetch()) {
+			$b_ids[] = (integer) $rs->post_id;
+			$b_tbs[] = (integer) $rs->comment_trackback;
+			$b_nbs[] = (integer) $rs->nb_comment;
+		}
+		
+		# c) Update comments numbers on posts
+		# This compare previous requests to update also posts without comment
 		$cur = $this->con->openCursor($this->prefix.'post');
 		
-		if ($rs->isEmpty()) {
-			return;
+		foreach($a_ids as $a_key => $a_id)
+		{
+			$nb_comment = $nb_trackback = 0;
+			//$cur->nb_comment = $nb_comment;
+			foreach($b_ids as $b_key => $b_id)
+			{
+				if ($a_id != $b_id || $a_tbs[$a_key] != $b_tbs[$b_key]) {
+					continue;
+				}
+				
+				if ($b_tbs[$b_key]) {
+					$nb_trackback = $b_nbs[$b_key];
+				} else {
+					$nb_comment = $b_nbs[$b_key];
+				}
+			}
+			
+			if ($a_tbs[$a_key]) {
+				$cur->nb_trackback = $nb_trackback;
+			} else {
+				$cur->nb_comment = $nb_comment;
+			}
+			$cur->update('WHERE post_id = '.$a_id);
 		}
-		
-		if ($tb) {
-			$cur->nb_trackback = (integer) $rs->f(0);
-		} else {
-			$cur->nb_comment = (integer) $rs->f(0);
-		}
-		
-		$cur->update('WHERE post_id = '.(integer) $post_id);
 	}
 	//@}
 	
@@ -316,7 +366,7 @@ class dcBlog
 		}
 		
 		# We need to apply filter after counting
-		if (!empty($params['cat_id']))
+		if (isset($params['cat_id']) && $params['cat_id'] !== '')
 		{
 			$found = false;
 			foreach ($data as $v) {
@@ -331,7 +381,8 @@ class dcBlog
 			}
 		}
 		
-		if (!empty($params['cat_url']) && empty($params['cat_id']))
+		if (isset($params['cat_url']) && ($params['cat_url'] !== '') 
+			&& !isset($params['cat_id']))
 		{
 			$found = false;
 			foreach ($data as $v) {
@@ -458,7 +509,13 @@ class dcBlog
 		# --BEHAVIOR-- coreBeforeCategoryCreate
 		$this->core->callBehavior('coreBeforeCategoryCreate',$this,$cur);
 		
-		$this->categories()->addNode($cur,$parent);
+		$id = $this->categories()->addNode($cur,$parent);
+		# Update category's cursor
+		$rs = $this->getCategory($id);
+		if (!$rs->isEmpty()) {
+			$cur->cat_lft = $rs->cat_lft;
+			$cur->cat_rgt = $rs->cat_rgt;
+		}
 		
 		# --BEHAVIOR-- coreAfterCategoryCreate
 		$this->core->callBehavior('coreAfterCategoryCreate',$this,$cur);
@@ -578,7 +635,7 @@ class dcBlog
 	public function resetCategoriesOrder()
 	{
 		if (!$this->core->auth->check('categories',$this->id)) {
-			throw new Exception(__('You are not allowed to delete categories'));
+			throw new Exception(__('You are not allowed to reset categories order'));
 		}
 		
 		$this->categories()->resetOrder();
@@ -668,6 +725,10 @@ class dcBlog
 	*/
 	public function getPosts($params=array(),$count_only=false)
 	{
+		# --BEHAVIOR-- coreBlogBeforeGetPosts
+		$params = new ArrayObject($params);
+		$this->core->callBehavior('coreBlogBeforeGetPosts',$params);
+
 		if ($count_only)
 		{
 			$strReq = 'SELECT count(P.post_id) ';
@@ -740,7 +801,7 @@ class dcBlog
 			$strReq .= "AND post_type = 'post' ";
 		}
 		
-		if (!empty($params['post_id'])) {
+		if (isset($params['post_id']) && $params['post_id'] !== '') {
 			if (is_array($params['post_id'])) {
 				array_walk($params['post_id'],create_function('&$v,$k','if($v!==null){$v=(integer)$v;}'));
 			} else {
@@ -749,7 +810,7 @@ class dcBlog
 			$strReq .= 'AND P.post_id '.$this->con->in($params['post_id']);
 		}
 		
-		if (!empty($params['post_url'])) {
+		if (isset($params['post_url']) && $params['post_url'] !== '') {
 			$strReq .= "AND post_url = '".$this->con->escape($params['post_url'])."' ";
 		}
 		
@@ -757,7 +818,7 @@ class dcBlog
 			$strReq .= "AND U.user_id = '".$this->con->escape($params['user_id'])."' ";
 		}
 		
-		if (!empty($params['cat_id']))
+		if (isset($params['cat_id']) && $params['cat_id'] !== '')
 		{
 			if (!is_array($params['cat_id'])) {
 				$params['cat_id'] = array($params['cat_id']);
@@ -767,7 +828,7 @@ class dcBlog
 			}
 			$strReq .= 'AND '.$this->getPostsCategoryFilter($params['cat_id'],'cat_id').' ';
 		}
-		elseif (!empty($params['cat_url']))
+		elseif (isset($params['cat_url']) && $params['cat_url'] !== '')
 		{
 			if (!is_array($params['cat_url'])) {
 				$params['cat_url'] = array($params['cat_url']);
@@ -1004,10 +1065,10 @@ class dcBlog
 		
 		$cat_field = $catReq = $limit = '';
 		
-		if (!empty($params['cat_id'])) {
+		if (isset($params['cat_id']) && $params['cat_id'] !== '') {
 			$catReq = 'AND P.cat_id = '.(integer) $params['cat_id'].' ';
 			$cat_field = ', C.cat_url ';
-		} elseif (!empty($params['cat_url'])) {
+		} elseif (isset($params['cat_url']) && $params['cat_url'] !== '') {
 			$catReq = "AND C.cat_url = '".$this->con->escape($params['cat_url'])."' ";
 			$cat_field = ', C.cat_url ';
 		}
@@ -1216,28 +1277,32 @@ class dcBlog
 	@param	status	<b>integer</b>		Post status
 	*/
 	public function updPostStatus($id,$status)
+	{
+		$this->updPostsStatus($id,$status);
+	}
+	
+	/**
+	Updates posts status.
+	
+	@param	ids		<b>mixed</b>		Post(s) ID(s)
+	@param	status	<b>integer</b>		Post status
+	*/
+	public function updPostsStatus($ids,$status)
 	{
 		if (!$this->core->auth->check('publish,contentadmin',$this->id)) {
 			throw new Exception(__('You are not allowed to change this entry status'));
 		}
 		
-		$id = (integer) $id;
+		$posts_ids = dcUtils::cleanIds($ids);
 		$status = (integer) $status;
 		
+		$strReq = "WHERE blog_id = '".$this->con->escape($this->id)."' ".
+				"AND post_id ".$this->con->in($posts_ids);
+		
 		#If user can only publish, we need to check the post's owner
 		if (!$this->core->auth->check('contentadmin',$this->id))
 		{
-			$strReq = 'SELECT post_id '.
-					'FROM '.$this->prefix.'post '.
-					'WHERE post_id = '.$id.' '.
-					"AND blog_id = '".$this->con->escape($this->id)."' ".
-					"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
-			
-			$rs = $this->con->select($strReq);
-			
-			if ($rs->isEmpty()) {
-				throw new Exception(__('You are not allowed to change this entry status'));
-			}
+			$strReq .= "AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
 		}
 		
 		$cur = $this->con->openCursor($this->prefix.'post');
@@ -1245,36 +1310,43 @@ class dcBlog
 		$cur->post_status = $status;
 		$cur->post_upddt = date('Y-m-d H:i:s');
 		
-		$cur->update(
-			'WHERE post_id = '.$id.' '.
-			"AND blog_id = '".$this->con->escape($this->id)."' "
-			);
+		$cur->update($strReq);
 		$this->triggerBlog();
 	}
 	
+	/**
+	Updates post selection.
+	
+	@param	id		<b>integer</b>		Post ID
+	@param	selected	<b>integer</b>		Is selected post
+	*/
 	public function updPostSelected($id,$selected)
+	{
+		$this->updPostsSelected($id,$selected);
+	}
+	
+	/**
+	Updates posts selection.
+	
+	@param	ids		<b>mixed</b>		Post(s) ID(s)
+	@param	selected	<b>integer</b>		Is selected post(s)
+	*/
+	public function updPostsSelected($ids,$selected)
 	{
 		if (!$this->core->auth->check('usage,contentadmin',$this->id)) {
 			throw new Exception(__('You are not allowed to change this entry category'));
 		}
 		
-		$id = (integer) $id;
+		$posts_ids = dcUtils::cleanIds($ids);
 		$selected = (boolean) $selected;
 		
+		$strReq = "WHERE blog_id = '".$this->con->escape($this->id)."' ".
+				"AND post_id ".$this->con->in($posts_ids);
+		
 		# If user is only usage, we need to check the post's owner
 		if (!$this->core->auth->check('contentadmin',$this->id))
 		{
-			$strReq = 'SELECT post_id '.
-					'FROM '.$this->prefix.'post '.
-					'WHERE post_id = '.$id.' '.
-					"AND blog_id = '".$this->con->escape($this->id)."' ".
-					"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
-			
-			$rs = $this->con->select($strReq);
-			
-			if ($rs->isEmpty()) {
-				throw new Exception(__('You are not allowed to mark this entry as selected'));
-			}
+			$strReq .= "AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
 		}
 		
 		$cur = $this->con->openCursor($this->prefix.'post');
@@ -1282,10 +1354,7 @@ class dcBlog
 		$cur->post_selected = (integer) $selected;
 		$cur->post_upddt = date('Y-m-d H:i:s');
 		
-		$cur->update(
-			'WHERE post_id = '.$id.' '.
-			"AND blog_id = '".$this->con->escape($this->id)."' "
-		);
+		$cur->update($strReq);
 		$this->triggerBlog();
 	}
 	
@@ -1296,28 +1365,32 @@ class dcBlog
 	@param	cat_id	<b>integer</b>		Category ID
 	*/
 	public function updPostCategory($id,$cat_id)
+	{
+		$this->updPostsCategory($id,$cat_id);
+	}
+	
+	/**
+	Updates posts category. <var>$cat_id</var> can be null.
+	
+	@param	ids		<b>mixed</b>		Post(s) ID(s)
+	@param	cat_id	<b>integer</b>		Category ID
+	*/
+	public function updPostsCategory($ids,$cat_id)
 	{
 		if (!$this->core->auth->check('usage,contentadmin',$this->id)) {
 			throw new Exception(__('You are not allowed to change this entry category'));
 		}
 		
-		$id = (integer) $id;
+		$posts_ids = dcUtils::cleanIds($ids);
 		$cat_id = (integer) $cat_id;
 		
+		$strReq = "WHERE blog_id = '".$this->con->escape($this->id)."' ".
+				"AND post_id ".$this->con->in($posts_ids);
+		
 		# If user is only usage, we need to check the post's owner
 		if (!$this->core->auth->check('contentadmin',$this->id))
 		{
-			$strReq = 'SELECT post_id '.
-					'FROM '.$this->prefix.'post '.
-					'WHERE post_id = '.$id.' '.
-					"AND blog_id = '".$this->con->escape($this->id)."' ".
-					"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
-			
-			$rs = $this->con->select($strReq);
-			
-			if ($rs->isEmpty()) {
-				throw new Exception(__('You are not allowed to change this entry category'));
-			}
+			$strReq .= "AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
 		}
 		
 		$cur = $this->con->openCursor($this->prefix.'post');
@@ -1325,8 +1398,32 @@ class dcBlog
 		$cur->cat_id = ($cat_id ? $cat_id : null);
 		$cur->post_upddt = date('Y-m-d H:i:s');
 		
+		$cur->update($strReq);
+		$this->triggerBlog();
+	}
+	
+	/**
+	Updates posts category. <var>$new_cat_id</var> can be null.
+	
+	@param	old_cat_id	<b>integer</b>		Old category ID
+	@param	new_cat_id	<b>integer</b>		New category ID
+	*/
+	public function changePostsCategory($old_cat_id,$new_cat_id)
+	{
+		if (!$this->core->auth->check('contentadmin,categories',$this->id)) {
+			throw new Exception(__('You are not allowed to change entries category'));
+		}
+		
+		$old_cat_id = (integer) $old_cat_id;
+		$new_cat_id = (integer) $new_cat_id;
+		
+		$cur = $this->con->openCursor($this->prefix.'post');
+		
+		$cur->cat_id = ($new_cat_id ? $new_cat_id : null);
+		$cur->post_upddt = date('Y-m-d H:i:s');
+		
 		$cur->update(
-			'WHERE post_id = '.$id.' '.
+			'WHERE cat_id = '.$old_cat_id.' '.
 			"AND blog_id = '".$this->con->escape($this->id)."' "
 		);
 		$this->triggerBlog();
@@ -1338,38 +1435,37 @@ class dcBlog
 	@param	id		<b>integer</b>		Post ID
 	*/
 	public function delPost($id)
+	{
+		$this->delPosts($id);
+	}
+	
+	/**
+	Deletes multiple posts.
+	
+	@param	ids		<b>mixed</b>		Post(s) ID(s)
+	*/
+	public function delPosts($ids)
 	{
 		if (!$this->core->auth->check('delete,contentadmin',$this->id)) {
 			throw new Exception(__('You are not allowed to delete entries'));
 		}
 		
-		$id = (integer) $id;
+		$posts_ids = dcUtils::cleanIds($ids);
 		
-		if (empty($id)) {
+		if (empty($posts_ids)) {
 			throw new Exception(__('No such entry ID'));
 		}
 		
+		$strReq = 'DELETE FROM '.$this->prefix.'post '.
+				"WHERE blog_id = '".$this->con->escape($this->id)."' ".
+				"AND post_id ".$this->con->in($posts_ids);
+		
 		#If user can only delete, we need to check the post's owner
 		if (!$this->core->auth->check('contentadmin',$this->id))
 		{
-			$strReq = 'SELECT post_id '.
-					'FROM '.$this->prefix.'post '.
-					'WHERE post_id = '.$id.' '.
-					"AND blog_id = '".$this->con->escape($this->id)."' ".
-					"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
-			
-			$rs = $this->con->select($strReq);
-			
-			if ($rs->isEmpty()) {
-				throw new Exception(__('You are not allowed to delete this entry'));
-			}
+			$strReq .= "AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
 		}
 		
-		
-		$strReq = 'DELETE FROM '.$this->prefix.'post '.
-				'WHERE post_id = '.$id.' '.
-				"AND blog_id = '".$this->con->escape($this->id)."' ";
-		
 		$this->con->execute($strReq);
 		$this->triggerBlog();
 	}
@@ -1387,8 +1483,8 @@ class dcBlog
 		$rs = $this->con->select($strReq);
 		
 		$now = dt::toUTC(time());
-		$to_change = array();
-		
+		$to_change = new ArrayObject();
+
 		if ($rs->isEmpty()) {
 			return;
 		}
@@ -1406,18 +1502,23 @@ class dcBlog
 				$to_change[] = (integer) $rs->post_id;
 			}
 		}
-		
-		if (!empty($to_change))
+		if (count($to_change))
 		{
+			# --BEHAVIOR-- coreBeforeScheduledEntriesPublish
+			$this->core->callBehavior('coreBeforeScheduledEntriesPublish',$this,$to_change);
+
 			$strReq =
 			'UPDATE '.$this->prefix.'post SET '.
 			'post_status = 1 '.
 			"WHERE blog_id = '".$this->con->escape($this->id)."' ".
-			'AND post_id '.$this->con->in($to_change).' ';
-			
+			'AND post_id '.$this->con->in((array)$to_change).' ';
 			$this->con->execute($strReq);
 			$this->triggerBlog();
+
+			# --BEHAVIOR-- coreAfterScheduledEntriesPublish
+			$this->core->callBehavior('coreAfterScheduledEntriesPublish',$this,$to_change);
 		}
+		
 	}
 	
 	/**
@@ -1587,6 +1688,21 @@ class dcBlog
 		{
 			$this->core->initWikiPost();
 			$this->core->wiki2xhtml->setOpt('note_prefix','pnote-'.$post_id);
+			switch ($this->settings->system->note_title_tag) {
+				case 1:
+					$tag = 'h3';
+					break;
+				case 2:
+					$tag = 'p';
+					break;
+				default:
+					$tag = 'h4';
+					break;
+			}
+			$this->core->wiki2xhtml->setOpt('note_str','<div class="footnotes"><'.$tag.' class="footnotes-title">'.
+				__('Notes').'</'.$tag.'>%s</div>');
+			$this->core->wiki2xhtml->setOpt('note_str_single','<div class="footnotes"><'.$tag.' class="footnotes-title">'.
+				__('Note').'</'.$tag.'>%s</div>');
 			if (strpos($lang,'fr') === 0) {
 				$this->core->wiki2xhtml->setOpt('active_fr_syntax',1);
 			}
@@ -1794,15 +1910,15 @@ class dcBlog
 			$strReq .= 'AND post_type '.$this->con->in($params['post_type']);
 		}
 		
-		if (!empty($params['post_id'])) {
+		if (isset($params['post_id']) && $params['post_id'] !== '') {
 			$strReq .= 'AND P.post_id = '.(integer) $params['post_id'].' ';
 		}
 		
-		if (!empty($params['cat_id'])) {
+		if (isset($params['cat_id']) && $params['cat_id'] !== '') {
 			$strReq .= 'AND P.cat_id = '.(integer) $params['cat_id'].' ';
 		}
 		
-		if (!empty($params['comment_id'])) {
+		if (isset($params['comment_id']) && $params['comment_id'] !== '') {
 			$strReq .= 'AND comment_id = '.(integer) $params['comment_id'].' ';
 		}
 		
@@ -1820,7 +1936,8 @@ class dcBlog
 		}
 		
 		if (isset($params['comment_ip'])) {
-			$strReq .= "AND comment_ip = '".$this->con->escape($params['comment_ip'])."' ";
+			$comment_ip = $this->con->escape(str_replace('*','%',$params['comment_ip']));
+			$strReq .= "AND comment_ip LIKE '".$comment_ip."' ";
 		}
 		
 		if (isset($params['q_author'])) {
@@ -1992,14 +2109,63 @@ class dcBlog
 	@param	status	<b>integer</b>		Comment status
 	*/
 	public function updCommentStatus($id,$status)
+	{
+		$this->updCommentsStatus($id,$status);
+	}
+	
+	/**
+	Updates comments status.
+	
+	@param	ids		<b>mixed</b>		Comment(s) ID(s)
+	@param	status	<b>integer</b>		Comment status
+	*/
+	public function updCommentsStatus($ids,$status)
 	{
 		if (!$this->core->auth->check('publish,contentadmin',$this->id)) {
 			throw new Exception(__("You are not allowed to change this comment's status"));
 		}
 		
-		$cur = $this->con->openCursor($this->prefix.'comment');
-		$cur->comment_status = (integer) $status;
-		$this->updComment($id,$cur);
+		$co_ids = dcUtils::cleanIds($ids);
+		$status = (integer) $status;
+		
+		$strReq = 
+			'UPDATE '.$this->prefix.'comment tc ';
+		
+		# mySQL uses "JOIN" synthax
+		if ($this->con->driver() == 'mysql') {
+			$strReq .= 
+				'JOIN '.$this->prefix.'post tp ON tc.post_id = tp.post_id ';
+		}
+		
+		$strReq .= 
+			'SET comment_status = '.$status.' ';
+		
+		# pgSQL uses "FROM" synthax
+		if ($this->con->driver() != 'mysql') {
+			$strReq .= 
+				'FROM '.$this->prefix.'post tp ';
+		}
+		
+		$strReq .=
+			"WHERE blog_id = '".$this->con->escape($this->id)."' ".
+			'AND comment_id'.$this->con->in($co_ids);
+		
+		# add pgSQL "WHERE" clause
+		if ($this->con->driver() != 'mysql') {
+			$strReq .= 
+				'AND tc.post_id = tp.post_id ';
+		}
+		
+		#If user is only usage, we need to check the post's owner
+		if (!$this->core->auth->check('contentadmin',$this->id))
+		{
+			$strReq .= 
+				"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
+		}
+		
+		$this->con->execute($strReq);
+		$this->triggerComments($co_ids);
+		$this->triggerBlog();
 	}
 	
 	/**
@@ -2008,38 +2174,103 @@ class dcBlog
 	@param	id		<b>integer</b>		Comment ID
 	*/
 	public function delComment($id)
+	{
+		$this->delComments($id);
+	}
+	
+	/**
+	Delete comments
+	
+	@param	ids		<b>mixed</b>		Comment(s) ID(s)
+	*/
+	public function delComments($ids)
 	{
 		if (!$this->core->auth->check('delete,contentadmin',$this->id)) {
 			throw new Exception(__('You are not allowed to delete comments'));
 		}
 		
-		$id = (integer) $id;
+		$co_ids = dcUtils::cleanIds($ids);
 		
-		if (empty($id)) {
+		if (empty($co_ids)) {
 			throw new Exception(__('No such comment ID'));
 		}
 		
+		# Retrieve posts affected by comments edition
+		$affected_posts = array();
+		$strReq =
+			'SELECT distinct(post_id) '.
+			'FROM '.$this->prefix.'comment '.
+			'WHERE comment_id'.$this->con->in($co_ids);
+		
+		$rs = $this->con->select($strReq);
+		
+		while ($rs->fetch()) {
+			$affected_posts[] = (integer) $rs->post_id;
+		}
+		
+		# mySQL uses "INNER JOIN" synthax
+		if ($this->con->driver() == 'mysql') {
+			$strReq = 
+				'DELETE FROM tc '.
+				'USING '.$this->prefix.'comment tc '.
+				'INNER JOIN '.$this->prefix.'post tp ';
+		}
+		# pgSQL uses nothing special
+		else {
+			$strReq = 
+				'DELETE FROM '.$this->prefix.'comment tc '.
+				'USING '.$this->prefix.'post tp ';
+		}
+		
+		$strReq .= 
+			'WHERE tc.post_id = tp.post_id '.
+			"AND tp.blog_id = '".$this->con->escape($this->id)."' ".
+			'AND comment_id'.$this->con->in($co_ids);
+		
 		#If user can only delete, we need to check the post's owner
 		if (!$this->core->auth->check('contentadmin',$this->id))
 		{
-			$strReq = 'SELECT P.post_id '.
-					'FROM '.$this->prefix.'post P, '.$this->prefix.'comment C '.
-					'WHERE P.post_id = C.post_id '.
-					"AND P.blog_id = '".$this->con->escape($this->id)."' ".
-					'AND comment_id = '.$id.' '.
-					"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
-			
-			$rs = $this->con->select($strReq);
-			
-			if ($rs->isEmpty()) {
-				throw new Exception(__('You are not allowed to delete this comment'));
-			}
+			$strReq .= 
+				"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
 		}
 		
-		$strReq = 'DELETE FROM '.$this->prefix.'comment '.
-				'WHERE comment_id = '.$id.' ';
+		$this->con->execute($strReq);
+		$this->triggerComments($co_ids, true, $affected_posts);
+		$this->triggerBlog();
+	}
+
+	public function delJunkComments()
+	{
+		if (!$this->core->auth->check('delete,contentadmin',$this->id)) {
+			throw new Exception(__('You are not allowed to delete comments'));
+		}
+		
+		# mySQL uses "INNER JOIN" synthax
+		if ($this->con->driver() == 'mysql') {
+			$strReq = 
+				'DELETE FROM tc '.
+				'USING '.$this->prefix.'comment tc '.
+				'INNER JOIN '.$this->prefix.'post tp ';
+		}
+		# pgSQL uses nothing special
+		else {
+			$strReq = 
+				'DELETE FROM '.$this->prefix.'comment tc '.
+				'USING '.$this->prefix.'post tp ';
+		}
+		
+		$strReq .= 
+			'WHERE tc.post_id = tp.post_id '.
+			"AND tp.blog_id = '".$this->con->escape($this->id)."' ".
+			'AND comment_status = -2';
+		
+		#If user can only delete, we need to check the post's owner
+		if (!$this->core->auth->check('contentadmin',$this->id))
+		{
+			$strReq .= 
+				"AND user_id = '".$this->con->escape($this->core->auth->userID())."' ";
+		}
 		
-		$this->triggerComment($id,true);
 		$this->con->execute($strReq);
 		$this->triggerBlog();
 	}
@@ -2059,8 +2290,10 @@ class dcBlog
 		}
 		
 		if ($cur->comment_site !== null && $cur->comment_site != '') {
-			if (!preg_match('|^http(s?)://|',$cur->comment_site)) {
+			if (!preg_match('|^http(s?)://|i',$cur->comment_site, $matches)) {
 				$cur->comment_site = 'http://'.$cur->comment_site;
+			}else{
+				$cur->comment_site = strtolower($matches[0]).substr($cur->comment_site, strlen($matches[0]));
 			}
 		}
 		
