@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -496,9 +496,10 @@ class dcMedia extends filemanager
 	
 	@param	post_id	<b>integer</b>		Post ID
 	@param	media_id	<b>integer</b>		Optionnal media ID
-	@return	<b>array</b> Array of fileItems
+	@param	return_rs	<b>boolean</b>		Whether to return a resultset (true) or an array (false, default value).
+	@return	<b>array</b> Array or ResultSet of fileItems
 	*/
-	public function getPostMedia($post_id,$media_id=null)
+	public function getPostMedia($post_id,$media_id=null,$return_rs=false)
 	{
 		$params = array(
 			'post_id' => $post_id,
@@ -514,11 +515,11 @@ class dcMedia extends filemanager
 		while ($rs->fetch()) {
 			$f = $this->fileRecord($rs);
 			if ($f !== null) {
-				$res[] = $f;
+				$res[] = $return_rs ? new ArrayObject($f) : $f;
 			}
 		}
 		
-		return $res;
+		return $return_rs ? staticRecord::newFromArray($res) : $res;
 	}
 	
 	/**
@@ -820,6 +821,31 @@ class dcMedia extends filemanager
 		
 		$this->callFileHandler(files::getMimeType($media_file),'remove',$f);
 	}
+
+	/**
+	* Root directories
+	*
+	* Returns an array of directory under {@link $root} directory.
+	*
+	* @uses fileItem
+	* @return array
+	*/
+	public function getDBDirs()
+	{
+		$media_dir = $this->relpwd ? $this->relpwd : '.';
+		
+		$strReq =
+		'SELECT distinct media_dir '.
+		'FROM '.$this->table.' '.
+		"WHERE media_path = '".$this->path."'";
+		$rs = $this->con->select($strReq);
+		while ($rs->fetch()) {
+			if (is_dir($this->root.'/'.$rs->media_dir))
+				$dir[] = ($rs->media_dir == '.' ? '' : $rs->media_dir);
+		}
+		
+		return $dir;
+	}
 	
 	/**
 	Extract zip file in current location
@@ -911,8 +937,10 @@ class dcMedia extends filemanager
 				if (!file_exists($thumb_file) && $s[0] > 0 &&
 					($suffix == 'sq' || $w > $s[0] || $h > $s[0]))
 				{
+					$rate = ($s[0] < 100 ? 95 : ($s[0] < 600 ? 90 : 85));
 					$img->resize($s[0],$s[0],$s[1]);
-					$img->output('jpeg',$thumb_file,80);
+					$img->output('jpeg',$thumb_file,$rate);
+					$img->loadImage($file);
 				}
 			}
 			$img->close();
