@@ -2,7 +2,7 @@
 # -- BEGIN LICENSE BLOCK ---------------------------------------
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -165,6 +165,16 @@ class rsExtPost
 	{
 		return $rs->nb_trackback > 0;
 	}
+
+	/**
+	Returns whether post has been updated since publication.
+
+	@return <b>boolean</b>
+	*/
+	public static function isRepublished($rs)
+	{
+		return ($rs->getTS('upddt') + dt::getTimeOffset($rs->post_tz)) > $rs->getTS();
+	}
 	
 	/**
 	Returns full post URL.
