@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -304,6 +304,42 @@ function dotclearUpgrade($core)
 						"AND setting_value = '' ";
 				$core->con->execute($strReq);
 			}
+
+			if (version_compare($version,'2.5','<='))
+			{
+				# Try to disable daInstaller plugin if it has been installed outside the default plugins directory
+				$path = explode(PATH_SEPARATOR,DC_PLUGINS_ROOT);
+				$default = path::real(dirname(__FILE__).'/../../plugins/');
+				foreach ($path as $root)
+				{
+					if (!is_dir($root) || !is_readable($root)) {
+						continue;
+					}
+					if (substr($root,-1) != '/') {
+						$root .= '/';
+					}
+					if (($p = @dir($root)) === false) {
+						continue;
+					}
+					if(path::real($root) == $default) {
+						continue;
+					}
+					if (($d = @dir($root.'daInstaller')) === false) {
+						continue;
+					}
+					$f = $root.'/daInstaller/_disabled';
+					if (!file_exists($f))
+					{
+						@file_put_contents($f,'');
+					}
+				}
+			}
+
+			if (version_compare($version, '2.5.1', '<='))
+			{
+				// Flash enhanced upload no longer needed
+				@unlink(DC_ROOT.'/'.'inc/swf/swfupload.swf');
+			}
 			
 			$core->setVersion('core',DC_VERSION);
 			$core->blogDefaults();
