@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -15,7 +15,9 @@ $this->registerModule(
 	/* Name */			"Blowup Config",
 	/* Description*/		"Configure your Blowup Theme",
 	/* Author */			"Olivier Meunier",
-	/* Version */			'1.1',
-	/* Permissions */		'admin'
+	/* Version */			'1.2',
+	array(
+		'permissions' =>	'admin'
+	)
 );
 ?>
\ No newline at end of file
