@@ -1,9 +1,9 @@
 <?php
 # -- BEGIN LICENSE BLOCK ---------------------------------------
 #
-# This file is part of Dotclear 2.
+# This file is part of importExport, a plugin for DotClear2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2012 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -60,7 +60,7 @@ class dcImportWP extends dcIeModule
 	
 	protected function setInfo()
 	{
-		$this->type = 'i';
+		$this->type = 'import';
 		$this->name = __('WordPress import');
 		$this->description = __('Import a WordPress installation into your current blog.');
 	}
@@ -620,8 +620,14 @@ class dcImportWP extends dcIeModule
 		}
 		
 		$cur->post_format = $this->vars['post_formater'];
-		$cur->post_content = $this->cleanStr($rs->post_content);
-		$cur->post_excerpt = $this->cleanStr($rs->post_excerpt);
+		$_post_content = explode('<!--more-->',$rs->post_content,2);
+		if (count($_post_content) == 1) {
+			$cur->post_excerpt = NULL;
+			$cur->post_content = $this->cleanStr(array_shift($_post_content));
+		} else {
+			$cur->post_excerpt = $this->cleanStr(array_shift($_post_content));
+			$cur->post_content = $this->cleanStr(array_shift($_post_content));
+		}
 		
 		$cur->post_content_xhtml = $this->core->callFormater($this->vars['post_formater'],$cur->post_content);
 		$cur->post_excerpt_xhtml = $this->core->callFormater($this->vars['post_formater'],$cur->post_excerpt);
@@ -664,11 +670,14 @@ class dcImportWP extends dcIeModule
 		# Create tags
 		$this->importTags($rs->ID,$cur->post_id,$db);
 		
-		if (!$old_cat_ids->isEmpty() && $this->vars['cat_as_tags']) 
+		if (isset($old_cat_ids))
 		{
-			$old_cat_ids->moveStart();
-			while ($old_cat_ids->fetch()) {
-				$this->core->meta->setPostMeta($cur->post_id,'tag',$this->cleanStr($this->vars['cat_tags_prefix'].$old_cat_ids->name));
+			if (!$old_cat_ids->isEmpty() && $this->vars['cat_as_tags']) 
+			{
+				$old_cat_ids->moveStart();
+				while ($old_cat_ids->fetch()) {
+					$this->core->meta->setPostMeta($cur->post_id,'tag',$this->cleanStr($this->vars['cat_tags_prefix'].$old_cat_ids->name));
+				}
 			}
 		}
 	}
@@ -695,7 +704,7 @@ class dcImportWP extends dcIeModule
 			$cur->comment_ip        = $rs->comment_author_IP;
 			$cur->comment_trackback       = $rs->comment_type == 'trackback' ? 1 : 0;
 			$cur->comment_site = substr($this->cleanStr($rs->comment_author_url),0,255);
-			if (!isset($cur->comment_site)) $cur->comment_site = NULL;
+			if ($cur->comment_site == '') $cur->comment_site = NULL;
 			
 			if ($rs->comment_approved == 'spam') {
 				$cur->comment_status = -2;
@@ -779,4 +788,4 @@ class dcImportWP extends dcIeModule
 		}
 	}
 }
-?>
\ No newline at end of file
+?>
