@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -18,9 +18,15 @@ class pagesWidgets
 {
 	public static function initWidgets($w)
 	{
-		$w->create('pages',__('Pages'),array('tplPages','pagesWidget'));
+		$w->create('pages',__('Pages'),array('tplPages','pagesWidget'),null,'List of published pages');
 		$w->pages->setting('title',__('Title:'),__('Pages'));
-		$w->pages->setting('homeonly',__('Home page only'),1,'check');
+		$w->pages->setting('homeonly',__('Display on:'),1,'combo',
+			array(
+				__('All pages') => 0,
+				__('Home page only') => 1,
+				__('Except on home page') => 2
+				)
+		);
 		$w->pages->setting('sortby',__('Order by:'),'post_title','combo',
 			array(
 				__('Page title') => 'post_title',
@@ -31,6 +37,8 @@ class pagesWidgets
 		$w->pages->setting('orderby',__('Sort:'),'asc','combo',
 			array(__('Ascending') => 'asc', __('Descending') => 'desc')
 		);
+		$w->pages->setting('content_only',__('Content only'),0,'check');
+		$w->pages->setting('class',__('CSS class:'),'');
 	}
 	
 	public static function initDefaultWidgets($w,$d)
