@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -30,6 +30,7 @@ $post_status = $core->auth->getInfo('user_post_status');
 $post_position = 0;
 $post_open_comment = false;
 $post_open_tb = false;
+$post_selected = false;
 
 $post_media = array();
 
@@ -54,6 +55,7 @@ if (!$can_publish) {
 foreach ($core->blog->getAllPostStatus() as $k => $v) {
 	$status_combo[$v] = (string) $k;
 }
+$img_status_pattern = '<img class="img_select_option" alt="%1$s" title="%1$s" src="images/%2$s" />';
 
 # Formaters combo
 foreach ($core->getFormaters() as $v) {
@@ -75,6 +77,8 @@ while ($rs->fetch()) {
 unset($all_langs);
 unset($rs);
 
+# Validation flag
+$bad_dt = false;
 
 # Get page informations
 if (!empty($_REQUEST['id']))
@@ -107,6 +111,7 @@ if (!empty($_REQUEST['id']))
 		$post_position = (integer) $post->post_position;
 		$post_open_comment = (boolean) $post->post_open_comment;
 		$post_open_tb = (boolean) $post->post_open_tb;
+		$post_selected = (boolean) $post->post_selected;
 		
 		$page_title = __('Edit page');
 		
@@ -153,12 +158,24 @@ if (!empty($_POST) && $can_edit_page)
 	if (empty($_POST['post_dt'])) {
 		$post_dt = '';
 	} else {
-		$post_dt = strtotime($_POST['post_dt']);
-		$post_dt = date('Y-m-d H:i',$post_dt);
+		try
+		{
+			$post_dt = strtotime($_POST['post_dt']);
+			if ($post_dt == false || $post_dt == -1) {
+				$bad_dt = true;
+				throw new Exception(__('Invalid publication date'));
+			}
+			$post_dt = date('Y-m-d H:i',$post_dt);
+		}
+		catch (Exception $e)
+		{
+			$core->error->add($e->getMessage());
+		}
 	}
 	
 	$post_open_comment = !empty($_POST['post_open_comment']);
 	$post_open_tb = !empty($_POST['post_open_tb']);
+	$post_selected = !empty($_POST['post_selected']);
 	$post_lang = $_POST['post_lang'];
 	$post_password = !empty($_POST['post_password']) ? $_POST['post_password'] : null;
 	$post_position = (integer) $_POST['post_position'];
@@ -175,8 +192,21 @@ if (!empty($_POST) && $can_edit_page)
 	);
 }
 
-# Create or update post
-if (!empty($_POST) && !empty($_POST['save']) && $can_edit_page)
+# Delete page
+if (!empty($_POST['delete']) && $can_delete)
+{
+	try {
+		# --BEHAVIOR-- adminBeforePageDelete
+		$core->callBehavior('adminBeforePageDelete',$post_id);
+		$core->blog->delPost($post_id);
+		http::redirect($p_url);
+	} catch (Exception $e) {
+		$core->error->add($e->getMessage());
+	}
+}
+
+# Create or update page
+if (!empty($_POST) && !empty($_POST['save']) && $can_edit_page && !$bad_dt)
 {
 	$cur = $core->con->openCursor($core->prefix.'post');
 	
@@ -199,6 +229,7 @@ if (!empty($_POST) && !empty($_POST['save']) && $can_edit_page)
 	$cur->post_position = $post_position;
 	$cur->post_open_comment = (integer) $post_open_comment;
 	$cur->post_open_tb = (integer) $post_open_tb;
+	$cur->post_selected = (integer) $post_selected;
 	
 	if (isset($_POST['post_url'])) {
 		$cur->post_url = $post_url;
@@ -247,18 +278,6 @@ if (!empty($_POST) && !empty($_POST['save']) && $can_edit_page)
 	}
 }
 
-if (!empty($_POST['delete']) && $can_delete)
-{
-	try {
-		# --BEHAVIOR-- adminBeforePageDelete
-		$core->callBehavior('adminBeforePageDelete',$post_id);
-		$core->blog->delPost($post_id);
-		http::redirect($p_url);
-	} catch (Exception $e) {
-		$core->error->add($e->getMessage());
-	}
-}
-
 /* DISPLAY
 -------------------------------------------------------- */
 $default_tab = 'edit-entry';
@@ -282,6 +301,7 @@ if (!empty($_GET['co'])) {
   dcPage::jsDatePicker().
   dcPage::jsToolBar().
   dcPage::jsModal().
+  dcPage::jsMetaEditor().
   dcPage::jsLoad('js/_post.js').
   dcPage::jsConfirmClose('entry-form','comment-form').
   # --BEHAVIOR-- adminPageHeaders
@@ -296,16 +316,16 @@ if (!empty($_GET['co'])) {
 <?php
 
 if (!empty($_GET['upd'])) {
-		echo '<p class="message">'.__('Page has been successfully updated.').'</p>';
+	dcPage::message(__('Page has been successfully updated.'));
 }
 elseif (!empty($_GET['crea'])) {
-		echo '<p class="message">'.__('Page has been successfully created.').'</p>';
+	dcPage::message(__('Page has been successfully created.'));
 }
 elseif (!empty($_GET['attached'])) {
-	echo '<p class="message">'.__('File has been successfully attached.').'</p>';
+	dcPage::message(__('File has been successfully attached.'));
 }
 elseif (!empty($_GET['rmattach'])) {
-	echo '<p class="message">'.__('Attachment has been successfully removed.').'</p>';
+	dcPage::message(__('Attachment has been successfully removed.'));
 }
 
 # XHTML conversion
@@ -315,13 +335,29 @@ if (!empty($_GET['xconv']))
 	$post_content = $post_content_xhtml;
 	$post_format = 'xhtml';
 	
-	echo '<p class="message">'.__('Don\'t forget to validate your XHTML conversion by saving your post.').'</p>';
+	dcPage::message(__('Don\'t forget to validate your XHTML conversion by saving your post.'));
 }
 
 echo '<h2>'.html::escapeHTML($core->blog->name).
 ' &rsaquo; <a href="'.$p_url.'">'.__('Pages').'</a> &rsaquo; <span class="page-title">'.$page_title; 
 	if ($post_id) {
-		echo ' &ldquo;'.$post_title.'&rdquo;';
+		switch ($post_status) {
+			case 1:
+				$img_status = sprintf($img_status_pattern,__('published'),'check-on.png');
+				break;
+			case 0:
+				$img_status = sprintf($img_status_pattern,__('unpublished'),'check-off.png');
+				break;
+			case -1:
+				$img_status = sprintf($img_status_pattern,__('scheduled'),'scheduled.png');
+				break;
+			case -2:
+				$img_status = sprintf($img_status_pattern,__('pending'),'check-wrn.png');
+				break;
+			default:
+				$img_status = '';
+		}
+		echo ' &ldquo;'.$post_title.'&rdquo;'.' '.$img_status;
 	}
 echo	'</span></h2>';
 
@@ -395,9 +431,12 @@ if ($can_edit_page)
 		$core->auth->userID().'/'.
 		http::browserUID(DC_MASTER_KEY.$core->auth->userID().$core->auth->getInfo('user_pwd')).
 		'/'.$post->post_url);
-		echo '<a id="post-preview" href="'.$preview_url.'" class="button">'.__('Preview').'</a>';
+		echo '<a id="post-preview" href="'.$preview_url.'" class="button" accesskey="p">'.__('Preview').' (p)'.'</a>';
+	} else {
+		echo
+		'<a id="post-cancel" href="index.php" class="button" accesskey="c">'.__('Cancel').' (c)</a>';
 	}
-	
+
 	echo
 	($can_delete ? '<input type="submit" class="delete" value="'.__('Delete').'" name="delete" />' : '').
 	$core->formNonce().
@@ -414,7 +453,7 @@ if ($can_edit_page)
 	'</label></p>'.
 	
 	'<p><label for="post_dt">'.__('Published on:').
-	form::field('post_dt',16,16,$post_dt).'</label></p>'.
+	form::field('post_dt',16,16,$post_dt,($bad_dt ? 'invalid' : '')).'</label></p>'.
 	
 	'<p><label for="post_format">'.__('Text formating:').
 	form::combo('post_format',$formaters_combo,$post_format).
@@ -423,9 +462,26 @@ if ($can_edit_page)
 	
 	'<p><label for="post_open_comment" class="classic">'.form::checkbox('post_open_comment',1,$post_open_comment).' '.
 	__('Accept comments').'</label></p>'.
+	($core->blog->settings->system->allow_comments ? 
+		(isContributionAllowed($post_id,strtotime($post_dt),true) ? 
+			'' :
+			'<p class="form-note warn">'.__('Warning: Comments are not more accepted for this page.').'</p>') : 
+		'<p class="form-note warn">'.__('Warning: Comments are not accepted on this blog.').'</p>').
+
 	'<p><label for="post_open_tb" class="classic">'.form::checkbox('post_open_tb',1,$post_open_tb).' '.
 	__('Accept trackbacks').'</label></p>'.
+	($core->blog->settings->system->allow_trackbacks ? 
+		(isContributionAllowed($post_id,strtotime($post_dt),false) ? 
+			'' :
+			'<p class="form-note warn">'.__('Warning: Trackbacks are not more accepted for this page.').'</p>') : 
+		'<p class="form-note warn">'.__('Warning: Trackbacks are not accepted on this blog.').'</p>').
 	
+	'<p><label for="post_selected" class="classic">'.form::checkbox('post_selected',1,$post_selected).' '.
+	__('Hide').'</label></p>'.
+	'<p class="form-note">'.
+	__('If checked this page will be active but not listed in widget Pages.').
+	'</p>'.
+
 	'<p><label for="post_position" class="classic">'.__('Page position:').' '.
 	form::field('post_position',3,3,(string) $post_position).
 	'</label></p>'.
@@ -602,6 +658,27 @@ if ($post_id)
 	'</div>';
 }
 
+# Controls comments or trakbacks capabilities
+function isContributionAllowed($id,$dt,$com=true)
+{
+	global $core;
+
+	if (!$id) {
+		return true;
+	}
+	if ($com) {
+		if (($core->blog->settings->system->comments_ttl == 0) || 
+			(time() - $core->blog->settings->system->comments_ttl*86400 < $dt)) {
+			return true;
+		}
+	} else {
+		if (($core->blog->settings->system->trackbacks_ttl == 0) || 
+			(time() - $core->blog->settings->system->trackbacks_ttl*86400 < $dt)) {
+			return true;
+		}
+	}
+	return false;
+}
 
 # Show comments or trackbacks
 function showComments($rs,$has_action)
