@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -22,7 +22,9 @@ $core->tpl->addBlock('Tags',array('tplTags','Tags'));
 $core->tpl->addBlock('TagsHeader',array('tplTags','TagsHeader'));
 $core->tpl->addBlock('TagsFooter',array('tplTags','TagsFooter'));
 $core->tpl->addBlock('EntryTags',array('tplTags','EntryTags'));
+$core->tpl->addBlock('TagIf',array('tplTags','TagIf'));
 $core->tpl->addValue('TagID',array('tplTags','TagID'));
+$core->tpl->addValue('TagCount',array('tplTags','TagCount'));
 $core->tpl->addValue('TagPercent',array('tplTags','TagPercent'));
 $core->tpl->addValue('TagRoundPercent',array('tplTags','TagRoundPercent'));
 $core->tpl->addValue('TagURL',array('tplTags','TagURL'));
@@ -43,7 +45,6 @@ $core->tpl->addBlock('EntryMetaData',array('tplTags','EntryTags'));
 
 
 $core->addBehavior('templateBeforeBlock',array('behaviorsTags','templateBeforeBlock'));
-$core->addBehavior('tplSysIfConditions',array('behaviorsTags','tplSysIfConditions'));
 $core->addBehavior('publicBeforeDocument',array('behaviorsTags','addTplPath'));
 
 class behaviorsTags
@@ -54,8 +55,11 @@ class behaviorsTags
 		{
 			return
 			"<?php\n".
-			"@\$params['from'] .= ', '.\$core->prefix.'meta META ';\n".
-			"@\$params['sql'] .= 'AND META.post_id = P.post_id ';\n".
+			"if (!isset(\$params)) { \$params = array(); }\n".
+			"if (!isset(\$params['from'])) { \$params['from'] = ''; }\n".
+			"if (!isset(\$params['sql'])) { \$params['sql'] = ''; }\n".
+			"\$params['from'] .= ', '.\$core->prefix.'meta META ';\n".
+			"\$params['sql'] .= 'AND META.post_id = P.post_id ';\n".
 			"\$params['sql'] .= \"AND META.meta_type = 'tag' \";\n".
 			"\$params['sql'] .= \"AND META.meta_id = '".$core->con->escape($attr['tag'])."' \";\n".
 			"?>\n";
@@ -63,27 +67,18 @@ class behaviorsTags
 		elseif (empty($attr['no_context']) && ($b == 'Entries' || $b == 'Comments'))
 		{
 			return
-			'<?php if ($_ctx->exists("meta")) { '.
-				"@\$params['from'] .= ', '.\$core->prefix.'meta META ';\n".
-				"@\$params['sql'] .= 'AND META.post_id = P.post_id ';\n".
+			'<?php if ($_ctx->exists("meta") && ($_ctx->meta->meta_type == "tag")) { '.
+				"if (!isset(\$params)) { \$params = array(); }\n".
+				"if (!isset(\$params['from'])) { \$params['from'] = ''; }\n".
+				"if (!isset(\$params['sql'])) { \$params['sql'] = ''; }\n".
+				"\$params['from'] .= ', '.\$core->prefix.'meta META ';\n".
+				"\$params['sql'] .= 'AND META.post_id = P.post_id ';\n".
 				"\$params['sql'] .= \"AND META.meta_type = 'tag' \";\n".
 				"\$params['sql'] .= \"AND META.meta_id = '\".\$core->con->escape(\$_ctx->meta->meta_id).\"' \";\n".
 			"} ?>\n";
 		}
 	}
 	
-	public static function tplIfConditions($tag, $attr,$content,$if)
-	{
-		if ($tag == 'Sys' && isset($attr['has_tag'])) {
-			$sign = '';
-			if (substr($attr['has_tag'],0,1) == '!') {
-				$sign = '!';
-				$attr['has_tag'] = substr($attr['has_tag'],1);
-			}
-			$if[] =  $sign."(\$core->tpl->tagExists('".addslashes($attr['has_tag'])."') )";
-		}
-	}
-	
 	public static function addTplPath($core)
 	{
 		$core->tpl->setPath($core->tpl->getPath(), dirname(__FILE__).'/default-templates');
@@ -165,13 +160,35 @@ class tplTags
 		
 		return $res;
 	}
-	
+
+	public static function TagIf($attr,$content) 
+	{ 
+		$if = array();
+		$operateur = isset($attr['operator']) ? dcTemplate::getOperator($attr['operator']) : '&&';
+
+		if (isset($attr['has_entries'])) {
+			$sign = (boolean) $attr['has_entries'] ? '' : '!';
+			$if[] = $sign.'$_ctx->meta->count';
+		}
+
+		if (!empty($if)) {
+			return '<?php if('.implode(' '.$operateur.' ',$if).') : ?>'.$content.'<?php endif; ?>';
+		} else {
+			return $content;
+		}
+	}
+
 	public static function TagID($attr)
 	{
 		$f = $GLOBALS['core']->tpl->getFilters($attr);
 		return '<?php echo '.sprintf($f,'$_ctx->meta->meta_id').'; ?>';
 	}
 	
+	public static function TagCount($attr)
+	{
+		return '<?php echo $_ctx->meta->count; ?>';
+	}
+
 	public static function TagPercent($attr)
 	{
 		return '<?php echo $_ctx->meta->percent; ?>';
@@ -185,14 +202,14 @@ class tplTags
 	public static function TagURL($attr)
 	{
 		$f = $GLOBALS['core']->tpl->getFilters($attr);
-		return '<?php echo '.sprintf($f,'$core->blog->url.$core->url->getBase("tag").'.
-		'"/".rawurlencode($_ctx->meta->meta_id)').'; ?>';
+		return '<?php echo '.sprintf($f,'$core->blog->url.$core->url->getURLFor("tag",'.
+		'rawurlencode($_ctx->meta->meta_id))').'; ?>';
 	}
 	
 	public static function TagCloudURL($attr)
 	{
 		$f = $GLOBALS['core']->tpl->getFilters($attr);
-		return '<?php echo '.sprintf($f,'$core->blog->url.$core->url->getBase("tags")').'; ?>';
+		return '<?php echo '.sprintf($f,'$core->blog->url.$core->url->getURLFor("tags")').'; ?>';
 	}
 	
 	public static function TagFeedURL($attr)
@@ -204,8 +221,8 @@ class tplTags
 		}
 		
 		$f = $GLOBALS['core']->tpl->getFilters($attr);
-		return '<?php echo '.sprintf($f,'$core->blog->url.$core->url->getBase("tag_feed")."/".'.
-		'rawurlencode($_ctx->meta->meta_id)."/'.$type.'"').'; ?>';
+		return '<?php echo '.sprintf($f,'$core->blog->url.$core->url->getURLFor("tag_feed",'.
+		'rawurlencode($_ctx->meta->meta_id)."/'.$type.'")').'; ?>';
 	}
 	
 	# Widget function
@@ -213,6 +230,11 @@ class tplTags
 	{
 		global $core;
 		
+		if (($w->homeonly == 1 && $core->url->type != 'default') ||
+			($w->homeonly == 2 && $core->url->type == 'default')) {
+			return;
+		}
+
 		$params = array('meta_type' => 'tag');
 		
 		if ($w->limit !== '') {
@@ -239,15 +261,15 @@ class tplTags
 		$rs->sort($sort,$order);
 		
 		$res =
-		'<div class="tags">'.
+		($w->content_only ? '' : '<div class="tags'.($w->class ? ' '.html::escapeHTML($w->class) : '').'">').
 		($w->title ? '<h2>'.html::escapeHTML($w->title).'</h2>' : '').
 		'<ul>';
 		
 		while ($rs->fetch())
 		{
 			$res .=
-			'<li><a href="'.$core->blog->url.$core->url->getBase('tag').'/'.rawurlencode($rs->meta_id).'" '.
-			'class="tag'.$rs->roundpercent.'" rel="tag">'.
+			'<li><a href="'.$core->blog->url.$core->url->getURLFor('tag',rawurlencode($rs->meta_id)).'" '.
+			'class="tag'.$rs->roundpercent.'">'.
 			$rs->meta_id.'</a> </li>';
 		}
 		
@@ -256,11 +278,11 @@ class tplTags
 		if ($core->url->getBase('tags') && !is_null($w->alltagslinktitle) && $w->alltagslinktitle !== '')
 		{
 			$res .=
-			'<p><strong><a href="'.$core->blog->url.$core->url->getBase("tags").'">'.
+			'<p><strong><a href="'.$core->blog->url.$core->url->getURLFor("tags").'">'.
 			html::escapeHTML($w->alltagslinktitle).'</a></strong></p>';
 		}
 		
-		$res .= '</div>';
+		$res .= ($w->content_only ? '' : '</div>');
 		
 		return $res;
 	}
