@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -24,7 +24,7 @@ if (!defined('DC_CONTEXT_ADMIN')) { return; }
 
 <?php
 if (!empty($_GET['del'])) {
-	echo '<p class="message">'.__('Tag has been successfully removed').'</p>';
+	dcPage::message(__('Tag has been successfully removed'));
 }
 
 $tags = $core->meta->getMetadata(array('meta_type' => 'tag'));
